GcRootPtr

Struct GcRootPtr 

pub struct GcRootPtr<G>
where G: GcRuntime,
{ /* private fields */ }
A GcPtr that automatically roots and unroots its internal GcPtr.

Implementations

Source

impl<G> GcRootPtr<G>
where G: GcRuntime,

pub fn new(runtime: &Arc<G>, handle: GcPtr) -> Self

Constructs a new GCRootHandle from a runtime and a handle

pub fn runtime(&self) -> &Weak<G>

Returns the runtime that owns the memory

pub fn handle(&self) -> GcPtr

Returns the handle of this instance

pub fn unroot(self) -> GcPtr

Unroots the handle consuming self and returning the unrooted handle TODO: Should this simply return nothing, since the returned handle may be collected at any time?